Module render
rust_
fel
0.1.2
Module render
Module Items
Functions
In crate rust_
fel
rust_fel
Module
render
Module containing the functions to
render
and
rust_fel::re_render
the
rust_fel::App
.
Functions

re_
render
Used when a
rust_fel
struct
component updates it’s state and wants to propagate the changes to it’s children.
After first mount this function will update the Virtual
DOM
and then the real
DOM
.
It works by